@@ -3,6 +3,7 @@
 # Author: bdelbosc@nuxeo.com
 # Contributors: Tom Lazar
 #               Goutham Bhat
+#               Andrew McFague
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as published
@@ -22,6 +23,23 @@
 
 $Id: BenchRunner.py 24746 2005-08-31 09:59:27Z bdelbosc $
 """
+import os
+import platform
+import sys
+import threading
+import time
+import traceback
+import unittest
+from datetime import datetime
+from optparse import OptionParser, TitledHelpFormatter
+from socket import error as SocketError
+from thread import error as ThreadError
+from xmlrpclib import ServerProxy, Fault
+
+from FunkLoadHTTPServer import FunkLoadHTTPServer
+from utils import mmn_encode, set_recording_flag, recording, thread_sleep, \
+                  trace, red_str, green_str, get_version
+
 
 USAGE = """%prog [options] file class.method
 
@@ -48,24 +66,7 @@ try:
     psyco.full()
 except ImportError:
     pass
-import os
-import sys
-import platform
-import time
-from datetime import datetime
-import traceback
-import threading
-from socket import error as SocketError
-from thread import error as ThreadError
-from xmlrpclib import ServerProxy
-import unittest
-from optparse import OptionParser, TitledHelpFormatter
 
-from utils import mmn_encode, set_recording_flag, recording
-from utils import thread_sleep, trace, red_str, green_str
-from utils import get_version
-from FunkLoadHTTPServer import FunkLoadHTTPRequestHandler
-from FunkLoadHTTPServer import FunkLoadHTTPServer
 
 # ------------------------------------------------------------
 # utils
@@ -74,6 +75,7 @@ g_failures = 0                      # result of the bench
 g_errors = 0                        # result of the bench
 g_success = 0
 
+
 def add_cycle_result(status):
     """Count number of result."""
     # XXX use a thread.lock, but we don't mind if it is not accurate
@@ -86,11 +88,13 @@ def add_cycle_result(status):
     else:
         g_failures += 1
 
+
 def get_cycle_results():
     """Return counters."""
     global g_success, g_failures, g_errors
     return g_success, g_failures, g_errors
 
+
 def get_status(success, failures, errors, color=False):
     """Return a status and an exit code."""
     if errors:
@@ -125,7 +129,9 @@ def load_unittest(test_module, test_class, test_name, options):
 
 
 class ThreadSignaller:
-    """A simple class to signal whether a thread should continue running or stop."""
+    """
+    A simple class to signal whether a thread should continue running or stop.
+    """
     def __init__(self):
         self.keep_running = True
 
@@ -135,6 +141,7 @@ class ThreadSignaller:
     def set_running(self, val):
         self.keep_running = val
 
+
 class ThreadData:
     """Container for thread related data."""
     def __init__(self, thread, thread_id, thread_signaller):
@@ -164,7 +171,6 @@ class LoopTestRunner(threading.Thread):
         # this makes threads endings if main stop with a KeyboardInterupt
         self.setDaemon(1)
 
-
     def run(self):
         """Run a test in loop."""
         while (self.thread_signaller.running()):
@@ -201,10 +207,6 @@ class LoopTestRunner(threading.Thread):
             thread_sleep(self.sleep_time)
 
 
-
-# ------------------------------------------------------------
-#
-#
 class BenchRunner:
     """Run a unit test in bench mode."""
 
@@ -239,7 +241,8 @@ class BenchRunner:
         # setup monitoring
         monitor_hosts = []                  # list of (host, port, descr)
         if not options.is_distributed:
-            for host in test.conf_get('monitor', 'hosts', '', quiet=True).split():
+            hosts = test.conf_get('monitor', 'hosts', '', quiet=True).split()
+            for host in hosts:
                 host = host.strip()
                 monitor_hosts.append((host, test.conf_getInt(host, 'port'),
                                       test.conf_get(host, 'description', '')))
@@ -248,7 +251,6 @@ class BenchRunner:
         # and call setUp/tearDown Cycle
         self.test = test
 
-
     def run(self):
         """Run all the cycles.
 
@@ -261,7 +263,9 @@ class BenchRunner:
         self.logr_open()
         trace("* setUpBench hook: ...")
         self.test.setUpBench()
-        trace(' done.\n\n')
+        trace(' done.\n')
+        self.getMonitorsConfig()
+        trace('\n')
         for cvus in self.cycles:
             t_start = time.time()
             reset_cycle_results()
@@ -436,9 +440,11 @@ class BenchRunner:
         for thread_id, frame in frames.iteritems():
             stack = ''.join(traceback.format_stack(frame))
             stacks[stack] = stacks.setdefault(stack, []) + [thread_id]
+
         def sort_stack(x, y):
             """sort stack by number of thread."""
             return cmp(len(x[1]), len(y[1]))
+
         stacks = stacks.items()
         stacks.sort(sort_stack)
         for stack, thread_ids in stacks:
@@ -447,6 +453,31 @@ class BenchRunner:
             trace('-' * 72 + '\n')
             trace(stack + '\n')
 
+    def getMonitorsConfig(self):
+        """ Get monitors configuration from hosts """
+        if not self.monitor_hosts:
+            return
+        monitor_hosts = []
+        for (host, port, desc) in self.monitor_hosts:
+            trace("* Getting monitoring config from %s: ..." % host)
+            server = ServerProxy("http://%s:%s" % (host, port))
+            try:
+                config = server.getMonitorsConfig()
+                data = []
+                for key in config.keys():
+                    xml = '<monitorconfig host="%s" key="%s" value="%s" />' % (
+                                                        host, key, config[key])
+                    data.append(xml)
+                self.logr("\n".join(data))
+            except Fault:
+                trace(' not supported.\n')
+                monitor_hosts.append((host, port, desc))
+            except SocketError:
+                trace(' failed, server is down.\n')
+            else:
+                trace(' done.\n')
+                monitor_hosts.append((host, port, desc))
+        self.monitor_hosts = monitor_hosts
 
     def startMonitors(self, monitor_key):
         """Start monitoring on hosts list."""
@@ -465,7 +496,6 @@ class BenchRunner:
                 monitor_hosts.append((host, port, desc))
         self.monitor_hosts = monitor_hosts
 
-
     def stopMonitors(self, monitor_key):
         """Stop monitoring and save xml result."""
         if not self.monitor_hosts:
@@ -482,7 +512,6 @@ class BenchRunner:
                 trace(' done.\n')
                 self.logr(xml)
 
-
     def logr(self, message):
         """Log to the test result file."""
         self.test._logr(message, force=True)
@@ -544,12 +573,6 @@ class BenchRunner:
         return '\n'.join(text)
 
 
-
-
-
-# ------------------------------------------------------------
-# main
-#
 def main():
     """Default main."""
     # enable to load module in the current path
@@ -558,92 +581,139 @@ def main():
 
     parser = OptionParser(USAGE, formatter=TitledHelpFormatter(),
                           version="FunkLoad %s" % get_version())
-    parser.add_option("-u", "--url", type="string", dest="main_url",
+    parser.add_option("-u", "--url",
+                      type="string",
+                      dest="main_url",
                       help="Base URL to bench.")
-    parser.add_option("-c", "--cycles", type="string", dest="bench_cycles",
+    parser.add_option("-c", "--cycles",
+                      type="string",
+                      dest="bench_cycles",
                       help="Cycles to bench, this is a list of number of "
-                      "virtual concurrent users, "
-                      "to run a bench with 3 cycles with 5, 10 and 20 "
-                      "users use: -c 2:10:20")
-    parser.add_option("-D", "--duration", type="string", dest="bench_duration",
+                           "virtual concurrent users, to run a bench with 3"
+                           "cycles with 5, 10 and 20 users use: -c 2:10:20")
+    parser.add_option("-D", "--duration",
+                      type="string",
+                      dest="bench_duration",
                       help="Duration of a cycle in seconds.")
-    parser.add_option("-m", "--sleep-time-min", type="string",
+    parser.add_option("-m", "--sleep-time-min",
+                      type="string",
                       dest="bench_sleep_time_min",
                       help="Minimum sleep time between requests.")
-    parser.add_option("-M", "--sleep-time-max", type="string",
+    parser.add_option("-M", "--sleep-time-max",
+                      type="string",
                       dest="bench_sleep_time_max",
                       help="Maximum sleep time between requests.")
-    parser.add_option("-t", "--test-sleep-time", type="string",
+    parser.add_option("-t", "--test-sleep-time",
+                      type="string",
                       dest="bench_sleep_time",
                       help="Sleep time between tests.")
-    parser.add_option("-s", "--startup-delay", type="string",
+    parser.add_option("-s", "--startup-delay",
+                      type="string",
                       dest="bench_startup_delay",
                       help="Startup delay between thread.")
-    parser.add_option("-f", "--as-fast-as-possible", action="store_true",
-                      help="Remove sleep times between requests and"
-                      " between tests, shortcut for -m0 -M0 -t0")
-    parser.add_option("", "--no-color", action="store_true",
+    parser.add_option("-f", "--as-fast-as-possible",
+                      action="store_true",
+                      help="Remove sleep times between requests and between "
+                           "tests, shortcut for -m0 -M0 -t0")
+    parser.add_option("", "--no-color",
+                      action="store_true",
                       help="Monochrome output.")
-    parser.add_option("", "--accept-invalid-links", action="store_true",
-                      help="Do not fail if css/image links are "
-                      "not reachable.")
-    parser.add_option("", "--simple-fetch", action="store_true",
+    parser.add_option("", "--accept-invalid-links",
+                      action="store_true",
+                      help="Do not fail if css/image links are not reachable.")
+    parser.add_option("", "--simple-fetch",
+                      action="store_true",
                       dest="bench_simple_fetch",
-                      help="Don't load additional links like css "
-                      "or images when fetching an html page.")
-    parser.add_option("-l", "--label", type="string",
-                      help="Add a label to this bench run "
-                      "for easier identification (it will be appended to the directory name "
-                      "for reports generated from it).")
-    parser.add_option("", "--enable-debug-server", action="store_true", dest="debugserver",
+                      help="Don't load additional links like css or images "
+                           "when fetching an html page.")
+    parser.add_option("-l", "--label",
+                      type="string",
+                      help="Add a label to this bench run for easier "
+                           "identification (it will be appended to the "
+                           "directory name for reports generated from it).")
+    parser.add_option("--enable-debug-server",
+                      action="store_true",
+                      dest="debugserver",
                       help="Instantiates a debug HTTP server which exposes an "
-                      "interface using which parameters can be modified at "
-                      "run-time. Currently supported parameters: "
-                      "/cvu?inc=<integer> to increase the number of CVUs, "
-                      "/cvu?dec=<integer> to decrease the number of CVUs, "
-                      "/getcvu returns number of CVUs ")
-    parser.add_option("", "--debug-server-port", type="string", dest="debugport",
-                      help="Port at which debug server should run during the test")
-    
-    parser.add_option("","--distribute", action="store_true", dest="distribute",
-                      help="Distributes the CVUs over a group of worker machines "
-                      "that are defined in the section [workers]")
-    parser.add_option("","--distribute-workers", type="string", dest="workerlist",
-                      help="This parameter will  over-ride the list of workers defined "
-                      "in the config file. expected notation is uname@host,uname:pwd@host or just host...") 
-    parser.add_option("","--is-distributed", action="store_true", dest="is_distributed",
-                      help="This parameter is for internal use only. it signals to a "
-                      "worker node that it is in distributed mode and shouldn't "
-                      "perform certain actions.")
+                           "interface using which parameters can be modified "
+                           "at run-time. Currently supported parameters: "
+                           "/cvu?inc=<integer> to increase the number of "
+                           "CVUs, /cvu?dec=<integer> to decrease the number "
+                           "of CVUs, /getcvu returns number of CVUs ")
+    parser.add_option("--debug-server-port",
+                      type="string",
+                      dest="debugport",
+                      help="Port at which debug server should run during the "
+                           "test")
+    parser.add_option("--distribute",
+                      action="store_true",
+                      dest="distribute",
+                      help="Distributes the CVUs over a group of worker "
+                           "machines that are defined in the workers section")
+    parser.add_option("--distribute-workers",
+                      type="string",
+                      dest="workerlist",
+                      help="This parameter will  over-ride the list of "
+                           "workers defined in the config file. expected "
+                           "notation is uname@host,uname:pwd@host or just "
+                           "host...")
+    parser.add_option("--distribute-python",
+                      type="string",
+                      dest="python_bin",
+                      help="When running in distributed mode, this Python "
+                           "binary will be used across all hosts.")
+    parser.add_option("--is-distributed",
+                      action="store_true",
+                      dest="is_distributed",
+                      help="This parameter is for internal use only. it "
+                           "signals to a worker node that it is in "
+                           "distributed mode and shouldn't perform certain "
+                           "actions.")
+    parser.add_option("--distributed-packages",
+                      type="string",
+                      dest="distributed_packages",
+                      help="Additional packages to be passed to easy_install "
+                           "on remote machines when being run in distributed "
+                           "mode.")
 
     options, args = parser.parse_args()
-    cmd_args = " ".join([k for k in sys.argv[1:] if k.find('--distribute')<0])
+    # XXX What exactly is this checking for here??
+    cmd_args = " ".join([k for k in sys.argv[1:]
+                           if k.find('--distribute') < 0])
+
     if len(args) != 2:
         parser.error("incorrect number of arguments")
+
     if not args[1].count('.'):
-        parser.error("invalid argument should be class.method")
+        parser.error("invalid argument; should be [class].[method]")
+
     if options.as_fast_as_possible:
         options.bench_sleep_time_min = '0'
         options.bench_sleep_time_max = '0'
         options.bench_sleep_time = '0'
+
     klass, method = args[1].split('.')
     if options.distribute:
         from Distributed import DistributionMgr
         ret = None
         try:
-            distmgr = DistributionMgr( args[0] , klass, method, options, cmd_args )     
-            try:
-                distmgr.prepare_workers(allow_errors = True)
-                ret = distmgr.run()
-                distmgr.final_collect()
-            except KeyboardInterrupt:
-                trace("* ^C received *")
-                distmgr.abort()
-        except UserWarning,error:
+            distmgr = DistributionMgr(
+                args[0], klass, method, options, cmd_args)
+        except UserWarning, error:
             trace(red_str("Distribution failed with:%s \n" % (error)))
+
+        try:
+            distmgr.prepare_workers(allow_errors=True)
+            ret = distmgr.run()
+            distmgr.final_collect()
+        except KeyboardInterrupt:
+            trace("* ^C received *")
+            distmgr.abort()
+
         sys.exit(ret)
     else:
         bench = BenchRunner(args[0], klass, method, options)
+
         # Start a HTTP server optionally
         if options.debugserver == True:
             http_server_thread = FunkLoadHTTPServer(bench, options.debugport)
