@@ -26,8 +26,6 @@ from datetime import datetime
 from socket import error as SocketError
 from stat import S_ISREG, S_ISDIR
 from glob import glob
-from socket import error as SocketError
-from stat import S_ISREG, S_ISDIR
 from xml.etree.ElementTree import ElementTree
 from xmlrpclib import ServerProxy
 
@@ -365,7 +363,7 @@ class DistributionMgr(threading.Thread):
                 self.remote_res_dir, self.tarred_testsdir)
 
             if worker.isdir(virtual_env):
-                worker.execute("rmdir -rf %s" % virtual_env)
+                worker.execute("rm -rf %s" % virtual_env)
 
             worker.execute("mkdir -p %s" % virtual_env)
             worker.put(
@@ -382,7 +380,8 @@ class DistributionMgr(threading.Thread):
             remote_tarball = os.path.join(self.remote_res_dir, tarball)
 
             # setup funkload
-            cmd = "./bin/easy_install setuptools ez_setup {funkload}"
+            cmd = "./bin/easy_install setuptools ez_setup {funkload}".format(
+                funkload=self.funkload_location)
 
             if self.distributed_packages:
                 cmd += " %s" % self.distributed_packages
@@ -465,9 +464,6 @@ class DistributionMgr(threading.Thread):
                         in err_string.split("\n") if k.strip()))
             trace("\n")
 
-        self.stopMonitors()
-        self.logr_close()
-
         self.stopMonitors()
         self.correlate_statistics()
 
@@ -586,6 +582,8 @@ class DistributionMgr(threading.Thread):
 
     def correlate_statistics(self):
         result_path = None
+        if not self.monitor_hosts:
+            return
         for worker, results in self._worker_results.items():
             files = glob("%s/%s-*.xml" % (self.distribution_output,
                                           worker.host))
