@@ -1,5 +1,7 @@
-# (C) Copyright 2005 Nuxeo SAS <http://nuxeo.com>
+# (C) Copyright 2005-2011 Nuxeo SAS <http://nuxeo.com>
 # Author: bdelbosc@nuxeo.com
+# Contributors:
+#   Krzysztof A. Adamski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as published
@@ -92,6 +94,7 @@ class FunkLoadXmlParser:
         self.cycle_duration = 0
         self.stats = {}                 # cycle stats
         self.monitor = {}               # monitoring stats
+        self.monitorconfig = {}         # monitoring config
         self.config = {}
         self.error = {}
 
@@ -182,6 +185,10 @@ class FunkLoadXmlParser:
             host = attrs.get('host')
             stats = self.monitor.setdefault(host, [])
             stats.append(MonitorStat(attrs))
+        elif name =='monitorconfig':
+            host = attrs.get('host')
+            config = self.monitorconfig.setdefault(host, {})
+            config[attrs.get('key')]=attrs.get('value')
 
 
     def handleStartCdataSection(self):
@@ -280,18 +287,18 @@ def main():
             trace("Creating html report: ...")
             html_path = RenderHtml(xml_parser.config, xml_parser.stats,
                                    xml_parser.error, xml_parser.monitor,
-                                   options)()
+                                   xml_parser.monitorconfig, options)()
             trace("done: \n")
             trace(html_path + "\n")
         elif options.org:
             from ReportRenderOrg import RenderOrg
-            print str(RenderOrg(xml_parser.config, xml_parser.stats,
+            print unicode(RenderOrg(xml_parser.config, xml_parser.stats,
                                 xml_parser.error, xml_parser.monitor,
-                                options))
+                                xml_parser.monitorconfig, options)).encode("utf-8")
         else:
-            print str(RenderRst(xml_parser.config, xml_parser.stats,
+            print unicode(RenderRst(xml_parser.config, xml_parser.stats,
                                 xml_parser.error, xml_parser.monitor,
-                                options))
+                                xml_parser.monitorconfig, options)).encode("utf-8")
 
 
 if __name__ == '__main__':
