@@ -1,6 +1,8 @@
-# (C) Copyright 2005 Nuxeo SAS <http://nuxeo.com>
+# (C) Copyright 2005-2011 Nuxeo SAS <http://nuxeo.com>
 # Author: bdelbosc@nuxeo.com
-# Contributors: Tom Lazar
+# Contributors:
+#   Tom Lazar
+#   Krzysztof A. Adamski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as published
@@ -22,7 +24,7 @@ $Id$
 """
 import os
 from shutil import copyfile
-from ReportRenderRst import RenderRst
+from ReportRenderRst import RenderRst, rst_title
 
 
 class RenderHtmlBase(RenderRst):
@@ -33,8 +35,8 @@ class RenderHtmlBase(RenderRst):
     chart_size = (350, 250)
     big_chart_size = (640, 480)
 
-    def __init__(self, config, stats, error, monitor, options, css_file=None):
-        RenderRst.__init__(self, config, stats, error, monitor, options)
+    def __init__(self, config, stats, error, monitor, monitorconfig, options, css_file=None):
+        RenderRst.__init__(self, config, stats, error, monitor, monitorconfig, options)
         self.css_file = css_file
         self.report_dir = self.css_path = self.rst_path = self.html_path = None
 
@@ -82,7 +84,7 @@ class RenderHtmlBase(RenderRst):
         """Create the ReST file."""
         rst_path = os.path.join(self.report_dir, 'index.rst')
         f = open(rst_path, 'w')
-        f.write(str(self))
+        f.write(unicode(self).encode("utf-8"))
         f.close()
         self.rst_path = rst_path
 
@@ -140,13 +142,23 @@ class RenderHtmlBase(RenderRst):
 
     def createCharts(self):
         """Create all charts."""
-        self.createMonitorCharts()
         self.createTestChart()
         self.createPageChart()
         self.createAllResponseChart()
         for step_name in self.steps:
             self.createResponseChart(step_name)
 
+    # monitoring charts
+    def createMonitorCharts(self):
+        """Create all montirored server charts."""
+        if not self.monitor or not self.with_chart:
+            return
+        self.append(rst_title("Monitored hosts", 2))
+        charts={}
+        for host in self.monitor.keys():
+            charts[host]=self.createMonitorChart(host)
+        return charts
+
     def createTestChart(self):
         """Create the test chart."""
 
@@ -159,9 +171,6 @@ class RenderHtmlBase(RenderRst):
     def createResponseChart(self, step):
         """Create responses chart."""
 
-    def createMonitorCharts(self):
-        """Create all montirored server charts."""
-
     def createMonitorChart(self, host):
         """Create monitrored server charts."""
 
