@@ -22,6 +22,7 @@ $Id$
 import os
 from shutil import copyfile
 from utils import get_version
+from MonitorPluginsDefault import MonitorCPU, MonitorMemFree, MonitorNetwork, MonitorCUs
 
 LI = '*'
 # ------------------------------------------------------------
@@ -229,11 +230,12 @@ class RenderRst:
     # number of slowest requests to display
     slowest_items = 5
 
-    def __init__(self, config, stats, error, monitor, options):
+    def __init__(self, config, stats, error, monitor, monitorconfig, options):
         self.config = config
         self.stats = stats
         self.error = error
         self.monitor = monitor
+        self.monitorconfig = monitorconfig
         self.options = options
         self.rst = []
 
@@ -471,21 +473,29 @@ class RenderRst:
             self.append('')
             self.renderCyclesStepStat(step_name)
 
+
+    def createMonitorCharts(self):
+        pass
+
     def renderMonitors(self):
         """Render all monitored hosts."""
         if not self.monitor or not self.with_chart:
             return
-        self.append(rst_title("Monitored hosts", 2))
-        for host in self.monitor.keys():
-            self.renderMonitor(host)
+        charts = self.createMonitorCharts()
+        if charts == None:
+            return
+        for host in charts.keys():
+            self.renderMonitor(host, charts[host])
 
-    def renderMonitor(self, host):
+
+    def renderMonitor(self, host, charts):
         """Render a monitored host."""
         description = self.config.get(host, '')
-        self.append(rst_title("%s: %s" % (host, description), 3))
-        self.append("**Load average**\n\n.. image:: %s_load.png\n" % host)
-        self.append("**Memory usage**\n\n.. image:: %s_mem.png\n" % host)
-        self.append("**Network traffic**\n\n.. image:: %s_net.png\n" % host)
+        if len(charts)>0:
+            self.append(rst_title("%s: %s" % (host, description), 3))
+        for chart in charts:
+            self.append("**%s**\n\n.. image:: %s\n" % (
+                    chart[0], os.path.basename(chart[1])))
 
     def renderSlowestRequests(self, number):
         """Render the n slowest requests of the best cycle."""
@@ -650,5 +660,12 @@ class RenderRst:
         self.renderHook()
         return '\n'.join(self.rst)
 
-
+    def getMonitorConfig(self, host):
+        """Return the host config or a default for backward compat"""
+        if host in self.monitorconfig:
+            return self.monitorconfig[host]
+        return {'MonitorCPU': MonitorCPU().getConfig(),
+                'MonitorMemFree': MonitorMemFree().getConfig(),
+                'MonitorNetwork': MonitorNetwork(None).getConfig(),
+                'MonitorCUs': MonitorCUs().getConfig()}
 
